<div align="center">

# GraiaX Shortcut

_Utilities for Graia Framework Community._

[![PyPI](https://img.shields.io/pypi/v/graiax-shortcut)](https://pypi.org/project/graiax-shortcut)
[![Python Version](https://img.shields.io/pypi/pyversions/graiax-shortcut)](https://pypi.org/project/graiax-shortcut)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://pycqa.github.io/isort/)
[![License](https://img.shields.io/github/license/GraiaCommunity/Shortcut)](https://github.com/GraiaCommunity/Shortcut/blob/master/LICENSE)
[![pdm-managed](https://img.shields.io/badge/pdm-managed-blueviolet)](https://pdm.fming.dev)

</div>
